@@ -208,7 +208,7 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 212 "giscanner/scannerparser.y" /* yacc.c:1909  */
+#line 212 "/home/fmuellner/src/gobject-introspection/giscanner/scannerparser.y" /* yacc.c:1909  */
 
   char *str;
   GList *list;
